==> kap_lib-v1.28.9-mc1.21.1-sources.jar: net/kapitencraft/kap_lib/util/attribute/BaseAttributeLocations.java <==
package net.kapitencraft.kap_lib.util.attribute;

import net.kapitencraft.kap_lib.KapLibMod;
import net.minecraft.resources.ResourceLocation;

public class BaseAttributeLocations {
    public static final ResourceLocation LUCK = ResourceLocation.withDefaultNamespace("base_luck");
    public static final ResourceLocation BLOCK_BREAK_SPEED = ResourceLocation.withDefaultNamespace("base_block_break_speed");
    public static final ResourceLocation BLOCK_INTERACTION_RANGE = ResourceLocation.withDefaultNamespace("base_block_interaction_range");
    public static final ResourceLocation ENTITY_INTERACTION_RANGE = ResourceLocation.withDefaultNamespace("base_entity_interaction_range");
    public static final ResourceLocation MINING_EFFICIENCY = ResourceLocation.withDefaultNamespace("base_mining_efficiency");
    public static final ResourceLocation ATTACK_KNOCKBACK = ResourceLocation.withDefaultNamespace("base_attack_knockback");
    public static final ResourceLocation BONUS_ATTACK_SPEED = KapLibMod.res("base_bonus_attack_speed");
    public static final ResourceLocation STRENGTH = KapLibMod.res("base_strength");
    public static final ResourceLocation CRIT_DAMAGE = KapLibMod.res("base_crit_damage");
    public static final ResourceLocation CRIT_CHANCE = KapLibMod.res("base_crit_chance");
    public static final ResourceLocation FEROCITY = KapLibMod.res("base_ferocity");
    public static final ResourceLocation INTELLIGENCE = KapLibMod.res("base_intelligence");
    public static final ResourceLocation ABILITY_DAMAGE = KapLibMod.res("base_ability_damage");
    public static final ResourceLocation RANGED_DAMAGE = KapLibMod.res("base_ranged_damage");
    public static final ResourceLocation DRAW_SPEED = KapLibMod.res("base_draw_speed");
    public static final ResourceLocation PROJECTILE_SPEED = KapLibMod.res("base_projectile_speed");
    public static final ResourceLocation PRISTINE = KapLibMod.res("base_pristine");
    public static final ResourceLocation MINING_FORTUNE = KapLibMod.res("base_mining_fortune");
    public static final ResourceLocation COOLDOWN_REDUCTION = KapLibMod.res("base_cooldown_reduction");
    public static final ResourceLocation LIVE_STEAL = KapLibMod.res("base_live_steal");
    public static final ResourceLocation ARMOR_SHREDDER = KapLibMod.res("base_armor_shredder");
    public static final ResourceLocation FISHING_SPEED = KapLibMod.res("base_fishing_speed");
    public static final ResourceLocation WISDOM = KapLibMod.res("base_wisdom");
    public static final ResourceLocation MANA_COST = KapLibMod.res("base_mana_cost");
}

==> kap_lib-v1.30.0-mc1.21.1-sources.jar: net/kapitencraft/kap_lib/util/attribute/BaseAttributeLocations.java <==
package net.kapitencraft.kap_lib.util.attribute;

import net.kapitencraft.kap_lib.KapLibMod;
import net.minecraft.resources.ResourceLocation;

public class BaseAttributeLocations {
    public static final ResourceLocation LUCK = ResourceLocation.withDefaultNamespace("base_luck");
    public static final ResourceLocation BLOCK_BREAK_SPEED = ResourceLocation.withDefaultNamespace("base_block_break_speed");
    public static final ResourceLocation BLOCK_INTERACTION_RANGE = ResourceLocation.withDefaultNamespace("base_block_interaction_range");
    public static final ResourceLocation ENTITY_INTERACTION_RANGE = ResourceLocation.withDefaultNamespace("base_entity_interaction_range");
    public static final ResourceLocation MINING_EFFICIENCY = ResourceLocation.withDefaultNamespace("base_mining_efficiency");
    public static final ResourceLocation ATTACK_KNOCKBACK = ResourceLocation.withDefaultNamespace("base_attack_knockback");
    public static final ResourceLocation BONUS_ATTACK_SPEED = KapLibMod.res("base_bonus_attack_speed");
    public static final ResourceLocation STRENGTH = KapLibMod.res("base_strength");
    public static final ResourceLocation CRIT_DAMAGE = KapLibMod.res("base_crit_damage");
    public static final ResourceLocation CRIT_CHANCE = KapLibMod.res("base_crit_chance");
    public static final ResourceLocation FEROCITY = KapLibMod.res("base_ferocity");
    public static final ResourceLocation MAGIC_DAMAGE = KapLibMod.res("base_ability_damage");
    public static final ResourceLocation RANGED_DAMAGE = KapLibMod.res("base_ranged_damage");
    public static final ResourceLocation DRAW_SPEED = KapLibMod.res("base_draw_speed");
    public static final ResourceLocation PROJECTILE_SPEED = KapLibMod.res("base_projectile_speed");
    public static final ResourceLocation PRISTINE = KapLibMod.res("base_pristine");
    public static final ResourceLocation MINING_FORTUNE = KapLibMod.res("base_mining_fortune");
    public static final ResourceLocation COOLDOWN_REDUCTION = KapLibMod.res("base_cooldown_reduction");
    public static final ResourceLocation LIVE_STEAL = KapLibMod.res("base_live_steal");
    public static final ResourceLocation ARMOR_SHREDDER = KapLibMod.res("base_armor_shredder");
    public static final ResourceLocation FISHING_SPEED = KapLibMod.res("base_fishing_speed");
    public static final ResourceLocation WISDOM = KapLibMod.res("base_wisdom");
    public static final ResourceLocation MANA_COST = KapLibMod.res("base_mana_cost");
}
